@@ -49,16 +49,19 @@ _UNITS.add_group(
         Unit("mbod"),
         Unit("usgpm"),
         Unit("usgpd"),
+        Unit("bbld", synonyms=["bbl/d"]),
     ],
     converters=[
         Converter("m3s", "mmscf", lambda m3s: m3s / 0.32774128),
         Converter("m3s", "mbod", lambda m3s: m3s / 0.00184013),
         Converter("m3s", "usgpm", lambda m3s: m3s * 15850),
         Converter("m3s", "usgpd", lambda m3s: m3s * 15850 * 1440),
+        Converter("m3s", "bbld", lambda m3s: m3s / 0.0000018401307),
         Converter("mmscf", "m3s", lambda mmscf: mmscf * 0.32774128),
         Converter("mbod", "m3s", lambda mbod: mbod * 0.00184013),
         Converter("usgpm", "m3s", lambda usgpm: usgpm / 15850),
         Converter("usgpd", "m3s", lambda usgpd: usgpd / (15850 * 1440)),
+        Converter("bbld", "m3s", lambda bbld: bbld * 0.0000018401307),
     ],
 )
 
